@@ -10,12 +10,12 @@ pub mod seal;
 mod registry;
 mod types;
 
-pub use crate::registry::{RegisteredPoStProof, RegisteredSealProof};
+pub use crate::registry::{RegisteredAggregationProof, RegisteredPoStProof, RegisteredSealProof};
 pub use crate::types::{PrivateReplicaInfo, PublicReplicaInfo};
 
 pub use filecoin_proofs_v1::types::{
-    ChallengeSeed, Commitment, PaddedBytesAmount, PieceInfo, PoStType, ProverId, Ticket,
-    UnpaddedByteIndex, UnpaddedBytesAmount,
+    AggregateSnarkProof, ChallengeSeed, Commitment, PaddedBytesAmount, PartitionSnarkProof,
+    PieceInfo, PoStType, ProverId, Ticket, UnpaddedByteIndex, UnpaddedBytesAmount,
 };
 pub use filecoin_proofs_v1::{FallbackPoStSectorProof, SnarkProof, VanillaProof};
 pub use fr32;
